@@ -1,5 +1,5 @@
 package XML::GrammarBase::Role::RelaxNG;
-$XML::GrammarBase::Role::RelaxNG::VERSION = '0.2.9';
+$XML::GrammarBase::Role::RelaxNG::VERSION = '0.2.10';
 use strict;
 use warnings;
 
@@ -7,7 +7,7 @@ use warnings;
 use MooX::Role 'late';
 
 use File::ShareDir qw(dist_dir);
-use XML::LibXML '2.0017';
+use XML::LibXML 2.0017;
 
 with('XML::GrammarBase::Role::DataDir');
 
@@ -97,7 +97,7 @@ XML::GrammarBase::Role::RelaxNG - base class for a RelaxNG validator
 
 =head1 VERSION
 
-version 0.2.9
+version 0.2.10
 
 =head1 SYNOPSIS
 
