@@ -1,5 +1,5 @@
 package XML::GrammarBase::Role::XSLT;
-$XML::GrammarBase::Role::XSLT::VERSION = '0.2.9';
+$XML::GrammarBase::Role::XSLT::VERSION = '0.2.10';
 use strict;
 use warnings;
 
@@ -9,8 +9,8 @@ use Package::Variant
 
 # use MooX 'late';
 
-use XML::LibXML '2.0017';
-use XML::LibXSLT '1.80';
+use XML::LibXML 2.0017;
+use XML::LibXSLT 1.80;
 
 use autodie;
 
@@ -49,7 +49,7 @@ XML::GrammarBase::Role::XSLT - a parameterized role for XSLT conversions.
 
 =head1 VERSION
 
-version 0.2.9
+version 0.2.10
 
 =head1 SYNOPSIS
 
