@@ -1,13 +1,13 @@
 package XML::GrammarBase::Role::XSLT::Global;
-$XML::GrammarBase::Role::XSLT::Global::VERSION = '0.2.9';
+$XML::GrammarBase::Role::XSLT::Global::VERSION = '0.2.10';
 use strict;
 use warnings;
 
 
 use MooX::Role 'late';
 
-use XML::LibXML '2.0017';
-use XML::LibXSLT '1.80';
+use XML::LibXML 2.0017;
+use XML::LibXSLT 1.80;
 
 use autodie;
 
@@ -149,7 +149,7 @@ XML::GrammarBase::Role::XSLT::Global - a base, non-parameterised, role for an XS
 
 =head1 VERSION
 
-version 0.2.9
+version 0.2.10
 
 =head1 SYNOPSIS
 
