@@ -3,11 +3,11 @@
 use strict;
 use warnings;
 
-use IO::All qw/ io /;
+use Path::Tiny qw/ path /;
 
 my ($version) =
     ( map { m{\Aversion *= *(\S+)\n?\z} ? ($1) : () }
-        io->file("./dist.ini")->getlines() );
+        path("./dist.ini")->lines_utf8() );
 
 if ( !defined($version) )
 {
